@@ -5,30 +5,37 @@ from terminal import bold, magenta, white, blue, green, red, yellow, confirm
 from oss2.exceptions import NoSuchKey,NoSuchBucket
 from ..const import CMD,WIN,PY2
 import json
+from batchcompute.utils.jsonizable import BatchEncoder
+
 
 PROGRESS_LEN = 50
 
 
-def all(jobId=None, taskName=None, instanceId=None,  description=False, all=False, top=10, state=None, id=None, name=None):
+def all(jobId=None, taskName=None, instanceId=None,  description=False, all=False, top=10, state=None, id=None, name=None,
+        show_json=False):
     if jobId:
         if instanceId:
-            getInstanceDetail(jobId, taskName, instanceId)
+            getInstanceDetail(jobId, taskName, instanceId, show_json)
         elif taskName:
-            getTaskDetail(jobId, taskName)
+            getTaskDetail(jobId, taskName, description, show_json)
         else:
-            getJobDetail(jobId, description)
+            getJobDetail(jobId, description, show_json)
 
     else:
-        list(top, all, state, id, name)
+        list(top, all, state, id, name, show_json)
 
 
-def list(num,all, state, jobId, jobName):
+def list(num,all, state, jobId, jobName, show_json=False):
 
     num = int(num)
 
     tip= []
     result = client.list_jobs()
 
+    if show_json:
+        print(json.dumps(result, indent=2 ,cls=BatchEncoder))
+        return
+
     arr = formater.items2arr(result.get('Items'))
     result_len = len(arr)
 
@@ -79,7 +86,8 @@ def list(num,all, state, jobId, jobName):
 
     print(white('  type "%s j <jobId|No.>" to show job detail\n' % (CMD)))
 
-def getJobDetail(jobId, descOnly):
+def getJobDetail(jobId, descOnly, show_json=False):
+
     jobId = result_cache.get(jobId, 'jobs')
 
     print(white('exec: bcs j %s%s' % (jobId, ' -d' if descOnly else '')))
@@ -91,6 +99,11 @@ def getJobDetail(jobId, descOnly):
         return
 
     result = client.get_job(jobId)
+
+    if show_json:
+        print(result)
+        return
+
     result = formater.to_dict(result)
     [result] = formater.format_date_in_arr([result], ['CreationTime', 'StartTime', 'EndTime'])
 
@@ -171,11 +184,11 @@ def getJobDetail(jobId, descOnly):
 
     print(white('\n  type "%s j <jobId|No.> <taskName|No.>" to show task detail\n' % CMD))
 
-def getTaskDetail(jobId, taskName):
+def getTaskDetail(jobId, taskName, descOnly, show_json=False):
     jobId = result_cache.get(jobId, 'jobs')
     taskName = result_cache.get(taskName, 'tasks')
 
-    print(white('exec: bcs j %s %s' %  (jobId,taskName) ))
+    print(white('exec: bcs j %s %s%s' %  (jobId, taskName, ' -d' if descOnly else '') ))
 
     jobDesc = client.get_job_description(jobId)
 
@@ -183,9 +196,14 @@ def getTaskDetail(jobId, taskName):
 
     taskInfo = formater.to_dict(taskInfo)
 
+
     taskInfo['Counts'] = calc_metric_count(taskInfo['InstanceMetrics'])
     taskDesc = jobDesc.DAG.Tasks[taskInfo['TaskName']]
 
+    if descOnly or show_json:
+        print(taskDesc)
+        return
+
     taskInfo['Cluster'] = util.get_cluster_str(taskDesc)
 
     arr = formater.format_date_in_arr([taskInfo], [ 'StartTime', 'EndTime'])
@@ -193,7 +211,11 @@ def getTaskDetail(jobId, taskName):
 
     # task
     print('%s' % bold(magenta('Task:')))
-    list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime','Elapsed','Cluster'], show_no=False)
+    clusterTitle = 'Cluster'
+    if taskDesc.get('AutoCluster'):
+        clusterTitle = 'AutoCluster %s' % (yellow('(ReserveOnFail)') if taskDesc['AutoCluster'].get('ReserveOnFail') else '')
+
+    list2table.print_table(arr, cols=['TaskName',('State', 'State', formater.get_job_state), 'Counts', 'StartTime', 'EndTime','Elapsed', ('Cluster',clusterTitle)], show_no=False)
 
     # task description
     print('%s' % bold(magenta('Task Description:')))
@@ -208,7 +230,36 @@ def getTaskDetail(jobId, taskName):
             print('  |--Data Disk: %s (%s) %sGB' % (
             disks['DataDisk']['MountPoint'], blue(disks['DataDisk']['Type']), disks['DataDisk']['Size']))
 
-        # vpc
+        # mounts
+        mounts = taskDesc['AutoCluster']['Configs']['Mounts']
+        print('%s (Locale: %s , Lock: %s , CacheSupport: %s)' % (
+        blue('Mounts:'), mounts.get('Locale'), mounts.get('Lock'), mounts.get('CacheSupport')))
+
+        entries = mounts.get('Entries')
+        if entries:
+            for ent in entries:
+                print('  |--%s %s %s' % (ent['Destination'], blue('<-'), green(ent['Source'])))
+
+        nas = mounts.get('  Nas')
+        if nas:
+            if nas.get('AccessGroup'):
+                print('    AccessGroup: %s' % (','.join(nas['AccessGroup'])))
+            if nas.get('FileSystem'):
+                print('    FileSystem: %s' % (','.join(nas['FileSystem'])))
+
+        oss = mounts.get('OSS')
+        if oss:
+            if oss.get('AccessKeyId'):
+                print('    AccessKeyId: %s' % nas['AccessGroup'])
+            if oss.get('AccessKeySecret'):
+                print('    AccessKeySecret: %s' % nas['AccessKeySecret'])
+            if oss.get('AccessSecurityToken'):
+                print('    AccessSecurityToken: %s' % nas['AccessSecurityToken'])
+
+
+
+
+        # Networks
         nw = taskDesc['AutoCluster']['Configs'].get('Networks')
         if nw:
             print(blue('Networks:'))
@@ -295,7 +346,7 @@ def getTaskDetail(jobId, taskName):
 
     print(white('\n  type "%s j <jobId|No.> <taskName|No.> <instanceId>" to show instance detail\n' % CMD))
 
-def getInstanceDetail(jobId, taskName, instanceId):
+def getInstanceDetail(jobId, taskName, instanceId, show_json=False):
     jobId = result_cache.get(jobId, 'jobs')
     taskName = result_cache.get(taskName, 'tasks')
 
@@ -303,6 +354,12 @@ def getInstanceDetail(jobId, taskName, instanceId):
 
     ins = client.get_instance(jobId, taskName, instanceId)
 
+
+    if show_json:
+        print(formater.to_dict(ins))
+        return
+
+
     arr = formater.format_date_in_arr([formater.to_dict(ins)], ['CreationTime', 'StartTime', 'EndTime'])
 
     print('%s' % bold(magenta('Instance:')))
@@ -337,6 +394,7 @@ def getInstanceDetail(jobId, taskName, instanceId):
 def showLog(osspath, jobId, taskName, instanceId, logType):
 
     osspath = formater.fix_log_path(osspath ,jobId,taskName, instanceId, logType)
+
     content = oss_client.get_data(osspath)
 
     print('%s' % bold(magenta('Log Content:')))
