@@ -8,18 +8,32 @@ import uuid
 import base64
 import tarfile
 from ..const import  PY3
+import socket
+import getpass
+
+
+def qsub(script_name, work_path=None, stderr_path=None, join='n',job_name=None, resource_list=None, stdout_path=None, env=False,
+
+
+         zz=False, xx=False,XX=False,additional_attributes=None,wpath=None,
+         variable_list=None, user_list=None,
+         prescript=None, array_request=None, path_list=None, rerunable=None, queue=None,
+         proxy_user=None, priority=None, mail_user_list=None, mail_optinos=None, keep=None,
+         interactively=False, hold=False, ff=False, root_path=None, directive_prefix=None,checkpoint_options=None,
+         seconds=None, account_string=None, date_time=None,
+
 
-def qsub(script_name, work_path=None, stderr_path=None, join='n',job_name=None, resource_list=None,queue=None, stdout_path=None, env=False,
          show_json=False, show_opt=False):
 
     # 参数
     opt = {
-        'job_name': job_name or 'qsub-job',
+        'shell': '/bin/bash',
+        'job_name': job_name or 'job',
         'script_name': script_name,
         'work_path': work_path,
         'stderr_path': stderr_path,
         'stdout_path': stdout_path,
-        'queue': queue,
+        #'queue': queue,
         'join': join,
         #'timeout': 0,
         'resource_list': parse_resource_list(resource_list or ''),
@@ -72,7 +86,7 @@ def qsub(script_name, work_path=None, stderr_path=None, join='n',job_name=None,
 
     #################################
     desc = to_job_desc(opt2)
-    desc['Name'] = opt2['job_name']
+    desc['Name'] = 'qsub-%s' % (opt2['job_name'] )
 
 
     ## 打包上传
@@ -85,7 +99,9 @@ def qsub(script_name, work_path=None, stderr_path=None, join='n',job_name=None,
         result = client.create_job(desc)
 
         if result.StatusCode == 201:
-            print(green('Job created: %s' % result.Id))
+            print(green('%s' % formater.hex_job_id(result.Id) ))
+
+
 
 def pack_upload(desc, opt, show_json):
 
@@ -127,15 +143,15 @@ def build_tar_from_arr_and_upload(arr, oss_path):
         os.remove(dist)
 
      # tar
-    print('pack %s' % dist)
+    #print('pack %s' % dist)
     with tarfile.open(dist, 'w|gz') as tar:
         for file in arr:
             fullpath = formater.get_abs_path(file)
-            print('add %s' % file)
+            #print('add %s' % file)
             tar.add(fullpath, arcname=os.path.basename(fullpath))
 
     # upload
-    print('Upload: %s ==> %s' % (dist, oss_path))
+    #print('Upload: %s ==> %s' % (dist, oss_path))
     oss_client.upload_file( dist, oss_path)
 
 
@@ -162,26 +178,27 @@ def to_job_desc(opt):
 
 
     clusterId = ''
-    que = opt.get('queue')
-    if que:
-        clusterId = getClusterIdFromQueue(opt.get('queue'))
+    # que = opt.get('queue')
+    # if que:
+    #     clusterId = getClusterIdFromQueue(opt.get('queue'))
 
-    if que and clusterId:
-        task['ClusterId'] = clusterId
+    # if que and clusterId:
+    #     task['ClusterId'] = clusterId
 
+    #else:
+
+    ## cpu mem
+    cpu = m.get('cpu') or 0
+    mem = m.get('mem') or 0
+
+    if cpu == 0 and mem == 0:
+        task['AutoCluster']['InstanceType'] = config.get_default_instance_type()
     else:
-        ## cpu mem
-        cpu = m.get('cpu') or 0
-        mem = m.get('mem') or 0
+        task['AutoCluster']['InstanceType'] = get_instance_type(cpu, mem)
 
-        if cpu == 0 and mem == 0:
-            task['AutoCluster']['InstanceType'] = config.get_default_instance_type()
-        else:
-            task['AutoCluster']['InstanceType'] = get_instance_type(cpu, mem)
-
-        #########
-        task['AutoCluster']["ResourceType"] = "OnDemand"
-        task['AutoCluster']['ImageId'] = config.get_default_image()
+    #########
+    task['AutoCluster']["ResourceType"] = "OnDemand"
+    task['AutoCluster']['ImageId'] = config.get_default_image()
 
     return job
 
@@ -215,7 +232,7 @@ def _gen_task_desc():
         "LogMapping": {},
         "InstanceCount": 1,
         "ClusterId": "",
-        "Mounts": m['Mounts'] if m else {},
+        "Mounts": ( m.get('Mounts') or {} ) if m else {},
         "AutoCluster": {
             'ReserveOnFail': False,
             'Configs': {
@@ -245,7 +262,7 @@ def _gen_job_desc():
             "Tasks": { },
             "Dependencies": {}
         },
-        "Description": "BatchCompute cli qsub job",
+        "Description": json.dumps({'type':'qsub','host':socket.gethostname(), 'user':getpass.getuser()}),
         "JobFailOnInstanceFail": True,
         "AutoRelease": False,
         "Priority": 1,
@@ -261,7 +278,14 @@ def parseScript(script_name):
     with open(pp, 'r') as f:
         lines = f.readlines()
 
-    m = {'resource_list':{}}
+    shell=''
+    try:
+        if len(lines)>0 and lines[0].startswith('#!'):
+            shell = lines[0].strip()
+    except:
+        pass
+
+    m = {'resource_list':{}, 'shell': shell}
     for line in lines:
         line = line.strip()
         if line.startswith('#'):
@@ -278,8 +302,9 @@ def parsePBS(m, line):
     '''
 
     line = line.strip()
-
-    if line.startswith('-l'):
+    if line.startswith('-N'):
+        m['job_name']=line[3:].strip()
+    elif line.startswith('-l'):
         m['resource_list'].update(parse_resource_list(line[3:].strip()))
     elif line.startswith('-d'):
         m['work_path']= line[3:].strip()
