@@ -1,3 +1,5 @@
+from requests.exceptions import StreamConsumedError
+
 from ..util import result_cache, oss_client, formater, client,smart_unicode
 from terminal import white,green,red,magenta,bold,yellow,blue
 import os
@@ -7,18 +9,23 @@ from ..const import WIN,PY2
 
 SLEN = 60
 
-def fetch(jobId, dir_path=None,stdout=False, stderr=False, taskName=None, instanceId=None):
+def fetch(jobId, dir_path=None,stdout=False, stderr=False, log_mapping=False, taskName=None, instanceId=None):
 
     if jobId.startswith('-'):
         raise Exception('Invalid jobId')
 
 
+
     jobId = result_cache.get(jobId, 'jobs')
+
+
+
     t = [jobId]
     if taskName:
         taskName = result_cache.get(taskName, 'tasks')
         t.append(taskName)
 
+
     if instanceId!=None:
         t.append(instanceId)
 
@@ -42,7 +49,7 @@ def fetch(jobId, dir_path=None,stdout=False, stderr=False, taskName=None, instan
         ins = formater.to_dict(ins)
 
         # log
-        print_ins_log(jobId, taskName, ins, stdout, stderr, dir_path)
+        print_ins_log(jobId, taskName, ins, stdout, stderr, log_mapping, dir_path)
 
         # result
         print_inst_result(jobId, taskName, ins, dir_path)
@@ -55,7 +62,7 @@ def fetch(jobId, dir_path=None,stdout=False, stderr=False, taskName=None, instan
 
         for ins in ins_items:
             # log
-            print_ins_log(jobId, taskName, ins, stdout, stderr, dir_path)
+            print_ins_log(jobId, taskName, ins, stdout, stderr, log_mapping, dir_path)
 
             # result
             print_inst_result(jobId, taskName, ins, dir_path)
@@ -73,7 +80,7 @@ def fetch(jobId, dir_path=None,stdout=False, stderr=False, taskName=None, instan
 
             for ins in ins_items:
                 # log
-                print_ins_log(jobId, taskName, ins, stdout, stderr, dir_path)
+                print_ins_log(jobId, taskName, ins, stdout, stderr, log_mapping, dir_path)
 
                 # result
                 print_inst_result(jobId, taskName, ins, dir_path)
@@ -82,6 +89,13 @@ def fetch(jobId, dir_path=None,stdout=False, stderr=False, taskName=None, instan
     if dir_path:
         print(green('done'))
 
+def getLogMappingPaths(m):
+    if not m:
+        return []
+    t = []
+    for k,v in m.items():
+        t.append('%s/%s' % (v, os.path.basename(k) ))
+    return t
 
 
 def print_inst_result(jobId, taskName, ins, dir_path):
@@ -108,9 +122,9 @@ def print_inst_result(jobId, taskName, ins, dir_path):
             print(white('-'*SLEN))
 
 
-def print_ins_log(jobId, taskName, ins, stdout, stderr, dir_path):
+def print_ins_log(jobId, taskName, ins, stdout, stderr, log_mapping, dir_path):
 
-    oss_path_arr = __get_ins_oss_path(jobId, taskName, ins, stdout, stderr)
+    oss_path_arr = __get_ins_oss_path(jobId, taskName, ins, stdout, stderr, log_mapping)
     if dir_path:
         for oss_path in oss_path_arr:
             download_log(oss_path, dir_path)
@@ -119,30 +133,63 @@ def print_ins_log(jobId, taskName, ins, stdout, stderr, dir_path):
             print_log(taskName, ins.get('InstanceId'),oss_path)
 
 
-def __get_ins_oss_path(jobId, taskName, ins, stdout, stderr):
+def __get_ins_oss_path(jobId, taskName , ins, stdout, stderr, log_mapping):
     instanceId = ins['InstanceId']
     t = []
-    if not stderr:
-        stdout_path = formater.fix_log_path(ins['StdoutRedirectPath'],jobId,taskName, instanceId, 'stdout')
+
+    if stdout or stderr or log_mapping:
+        if stdout:
+            stdout_path = formater.fix_log_path(ins['StdoutRedirectPath'],jobId,taskName, instanceId, 'stdout')
+            t.append(stdout_path)
+        elif stderr:
+            stderr_path = formater.fix_log_path(ins['StderrRedirectPath'],jobId,taskName, instanceId, 'stderr')
+            t.append(stderr_path)
+
+        elif log_mapping:
+            jobDesc = client.get_job_description(jobId)
+            jobDesc = formater.to_dict(jobDesc)
+            m = jobDesc['DAG']['Tasks'][taskName]['LogMapping']
+            for localPath, ossDir in m.items():
+                t.append('%s%s.%s.%s.%s' % (ossDir, os.path.basename(localPath), jobId, taskName, instanceId))
+
+
+    else:
+        # all
+        stdout_path = formater.fix_log_path(ins['StdoutRedirectPath'], jobId, taskName, instanceId, 'stdout')
         t.append(stdout_path)
-    if not stdout:
-        stderr_path = formater.fix_log_path(ins['StderrRedirectPath'],jobId,taskName, instanceId, 'stderr')
+        stderr_path = formater.fix_log_path(ins['StderrRedirectPath'], jobId, taskName, instanceId, 'stderr')
         t.append(stderr_path)
+
+        jobDesc = client.get_job_description(jobId)
+        jobDesc = formater.to_dict(jobDesc)
+        m = jobDesc['DAG']['Tasks'][taskName]['LogMapping']
+        for localPath, ossDir in m.items():
+            t.append('%s%s.%s.%s.%s' % (ossDir, os.path.basename(localPath), jobId, taskName, instanceId))
+
     return t
 
 
 def print_log(taskName, instId, oss_path):
     try:
         #file_name = oss_path[oss_path.rfind('/')+1:]
+        h = oss_client.head_data(oss_path)
+        if h.content_length > 1* 1024*1024:
+            print('''\n  Log file is too large to preview(size=%s), you can use 'bcs o cat -h' to preview or download it manually\n  %s\n''' % (h.content_length, oss_path))
+            return
+
         s = oss_client.get_data(oss_path)
+
         s = s.rstrip('\n\n')
         if len(s) > 0:
-            if 'stderr.job-' in oss_path:
+            if '/stderr.job-' in oss_path:
                 type='Stderr'
                 clor = yellow
-            else:
+            elif '/stdout.job-' in oss_path:
                 type='Stdout'
                 clor = green
+            else:
+                type = 'Log'
+                clor = None
 
             #print(white('='*SLEN))
             print('%s [%s:%s, %s:%s]' % (bold((type)), blue('TaskName'),magenta(taskName),blue('InstanceId'), magenta(instId) ))
@@ -151,11 +198,10 @@ def print_log(taskName, instId, oss_path):
             if WIN and PY2:
                 print(smart_unicode.format_utf8(s))
             else:
-                print(clor(s))
+                print(clor(s) if clor else s)
             print(white('-'*SLEN))
 
     except Exception as e:
-        #print(red(e))
         if not isinstance(e, NoSuchKey) and not isinstance(e, NoSuchBucket):
             raise e
 
