@@ -1,7 +1,7 @@
 from terminal import red, blue, bold, magenta, white
 from .externals.command import Command
 
-from . import const,i18n_util,cli_project,cli_oss,cli_qsub
+from . import const,i18n_util,cli_project,cli_oss,cli_pbs
 from .action import login, config, info, cluster,events, job, cluster_create, cluster_delete, cluster_update, instance_type \
     , job_delete, job_restart, job_stop, job_update, job_create, log_fetch, job_submit,checker\
     ,image,image_create,image_delete,disk_type,resource_type
@@ -98,6 +98,7 @@ class Cli:
                 1. %s r ''' % (COMMAND, CMD),
                                     spliter='\n    -----%s---------------------------' % blue('query, show'),
                                     func=resource_type.list)
+        cmd_resource_type.option('--show_json', MSG['resource_type']['option']['show_json'], visible=IS_GOD)
         self.program.action(cmd_resource_type)
 
         # instance type
@@ -109,6 +110,7 @@ class Cli:
 
             1. %s it ''' % (COMMAND, CMD),
                                     func=instance_type.list)
+        cmd_instance_type.option('--show_json', MSG['instance_type']['option']['show_json'], visible=IS_GOD)
         self.program.action(cmd_instance_type)
 
 
@@ -121,6 +123,8 @@ class Cli:
 
             1. %s d ''' % (COMMAND, CMD),
                                     func=disk_type.list)
+        cmd_disk_type.option('--show_json', MSG['disk_type']['option']['show_json'], visible=IS_GOD)
+
         self.program.action(cmd_disk_type)
 
         # events
@@ -132,6 +136,8 @@ class Cli:
 
                 1. %s e ''' % (COMMAND, CMD),
                                 func=events.list)
+        cmd_events.option('--show_json', MSG['event']['option']['show_json'], visible=IS_GOD)
+
         self.program.action(cmd_events)
 
 
@@ -153,6 +159,8 @@ class Cli:
               1. %s i img-6ki4fsea5ldlvsupbrk01q
               2. %s i 1''' % (COMMAND, CMD, CMD, CMD),
                                func=image.all)
+        cmd_images.option('-d,--description', MSG['image']['option']['description'])
+        cmd_images.option('--show_json', MSG['image']['option']['show_json'], visible=IS_GOD)
         self.program.action(cmd_images)
 
 
@@ -179,6 +187,7 @@ class Cli:
                                func=cluster.all)
         cmd_clusters.option('-d,--description', MSG['cluster']['option']['description'])
         cmd_clusters.option('-l,--log', MSG['cluster']['option']['oplog'])
+        cmd_clusters.option('--show_json', MSG['cluster']['option']['show_json'], visible=IS_GOD)
         self.program.action(cmd_clusters)
 
 
@@ -224,6 +233,7 @@ class Cli:
         cmd_job.option('-i, --id [jobId]', MSG['job']['option']['id'] )
         cmd_job.option('-n, --name [jobName]', MSG['job']['option']['name'] )
         cmd_job.option('-d, --description',  MSG['job']['option']['description'])
+        cmd_job.option('--show_json',  MSG['job']['option']['show_json'], visible=IS_GOD)
         self.program.action(cmd_job)
 
         # log
@@ -592,10 +602,23 @@ class Cli:
         ##############################################
 
         # qsub
-        cmd_qsub = cli_qsub.createCommand()
+        cmd_qsub = cli_pbs.qsub()
         self.program.action(cmd_qsub)
 
 
+        # qstat
+        cmd_qstat = cli_pbs.qstat()
+        self.program.action(cmd_qstat)
+
+        # qdel
+        cmd_qdel = cli_pbs.qdel()
+        self.program.action(cmd_qdel)
+
+        # # qhost
+        cmd_qhost = cli_pbs.qhost()
+        self.program.action(cmd_qhost)
+
+
         # check debug
         cmd_check = Command('check', alias=['ch'],
                                  arguments=['jobId'],
