@@ -37,25 +37,42 @@ def getJSON():
             "has_upgrade2":  "If fails with permission deny, try 'sudo pip install -U batchcompute-cli'"
         },
          "image": {
-            "description": 'show available images.'
+            "description": 'show available images.',
+             'option': {
+                 'description': 'show description of the cluster',
+                 'show_json': 'show json'
+             }
         },
         "disk_type": {
-            "description": 'show available disk types.'
+            "description": 'show available disk types.',
+             'option': {
+                 'show_json': 'show json'
+             }
         },
         "instance_type": {
-            "description": 'show available instance types.'
+            "description": 'show available instance types.',
+             'option': {
+                 'show_json': 'show json'
+             }
         },
         "resource_type": {
-            "description": 'show available resource types.'
+            "description": 'show available resource types.',
+             'option': {
+                 'show_json': 'show json'
+             }
         },
         "event": {
-            "description": 'show available events.'
+            "description": 'show available events.',
+             'option': {
+                 'show_json': 'show json'
+             }
         },
         "cluster": {
             "description": 'show cluster list, show cluster detail.',
             "option": {
                 'description': 'show description of the cluster',
                 'oplog' :'show operation logs. It works for showing cluster detail only.',
+                'show_json': 'show json',
             }
         },
         "job": {
@@ -66,7 +83,8 @@ def getJSON():
                 'state': 'state filter for listing jobs, scope: [Running|Stopped|Waiting|Finished|Failed]',
                 "id": 'jobId filter for listing jobs',
                 'name': 'jobName filter for listing jobs',
-                'description': 'show description of the job'
+                'description': 'show description of the job',
+                'show_json': 'show json'
             }
         },
         'log': {
@@ -326,6 +344,9 @@ def getJSON():
             },
             'cat': {
                 'description': 'print oss file content',
+                'option': {
+                    'byte_range': 'format: 100:1024, if just one number is given, such as: -b 100, it means: -b 0:100'
+                }
             },
             'copy': {
                 'description': 'copy oss file or folder',
@@ -383,5 +404,37 @@ def getJSON():
                 'show_json': 'optional,just output a BatchCompute job descrition json, won\'t submit a job',
                 'show_opt': 'optional,just output an options json, won\'t submit a job',
             }
+        },
+        'qstat': {
+            'description': '%sshow status of pbs batch jobs' % (
+            magenta('(New)')),
+            'option': {
+                'f': '''Specifies that a full status display be written to standard out.''',
+                'a': '''"All" jobs are displayed in the alternative format, see the Standard Output section.
+                                    If the operand is a destination id, all jobs at that destination are displayed.
+                                    If the operand is a job id, information about that job is displayed.''',
+                'i': '''Job status is displayed in the alternative format. For a destination id operand,
+                                    status for jobs at that destination which are not running are displayed.
+                                    This includes jobs which are queued, held or waiting.
+                                    If an operand is a job id, status for that job is displayed regardless of its state.''',
+                'r': '''If an operand is a job id, status for that job is displayed. For a destination id operand,
+                                    status for jobs at that destination which are running are displayed,
+                                    this includes jobs which are suspended.''',
+                'u': '''list jobs for in user_list'''
+            }
+        },
+        'qdel': {
+            'description': '%sDelete job' % (
+                magenta('(New)')),
+            'option': {
+                'W': '''Unsupported'''
+            }
+        },
+        'qhost': {
+            'description': '%sUnsupported' % (
+                magenta('(New)')),
+            'option': {
+
+            }
         }
     }
