@@ -55,25 +55,42 @@ def __get_json():
             "has_upgrade2": "如果提示没有权限, 请使用 'sudo pip install -U batchcompute-cli'"
         },
         "image": {
-            "description": '显示可用镜像列表.'
+            "description": '显示可用镜像列表.',
+            'option': {
+                'description': '获取集群描述JSON',
+                'show_json': '显示json信息'
+            }
         },
         "disk_type": {
-            "description": '显示可用磁盘类型列表.'
+            "description": '显示可用磁盘类型列表.',
+            'option': {
+                'show_json': '显示json信息'
+            }
         },
         "instance_type": {
-            "description": '显示实例类型列表.'
+            "description": '显示实例类型列表.',
+            'option': {
+                'show_json': '显示json信息'
+            }
         },
         "resource_type": {
-            "description": '显示资源类型列表.'
+            "description": '显示资源类型列表.',
+            'option': {
+                'show_json': '显示json信息'
+            }
         },
         "event": {
-            "description": '显示支持的事件.'
+            "description": '显示支持的事件.',
+            'option': {
+                'show_json': '显示json信息'
+            }
         },
         "cluster": {
             "description": '获取集群列表, 获取集群详情.',
             "option": {
                 'description': '获取集群描述JSON',
                 'oplog': '显示操作日志, 获取集群详情有效',
+                'show_json': '显示json信息'
             }
         },
         "job": {
@@ -84,7 +101,8 @@ def __get_json():
                 'state': '获取作业列表时, 按状态过滤, 取值范围: [Running|Stopped|Waiting|Finished|Failed]',
                 "id": '获取作业列表时, 按 JobId 模糊查询',
                 'name': '获取作业列表时, 按 JobName 模糊查询',
-                'description': '获取作业描述JSON'
+                'description': '获取作业描述JSON',
+                'show_json': '显示json信息'
             }
         },
         'log': {
@@ -335,6 +353,9 @@ def __get_json():
             },
             'cat': {
                 'description': '打印文件内容',
+                'option': {
+                    'byte_range': '请求获取的范围,格式: 100:1024, 如果为一个数字,如: -b 100,表示-b 0:100'
+                }
             },
             'copy': {
                 'description': '复制OSS文件或目录',
@@ -378,5 +399,30 @@ def __get_json():
                 'show_json': '只显示json不提交作业',
                 'show_opt': '只显示opt json不提交作业',
             }
+        },
+        'qstat': {
+            'description': '%s用于查询作业状态信息' % (
+                magenta('(New)')),
+            'option': {
+                'f': '''列出指定作业的信息''',
+                'a': '''列出系统所有作业''',
+                'i': '''列出不在运行的作业''',
+                'r': '''列出所有正在运行的作业''',
+                'u': '列出指定用户的作业'
+            }
+        },
+        'qdel': {
+            'description': '%s删除作业' % (
+                magenta('(New)')),
+            'option': {
+                'W': '''不支持'''
+            }
+        },
+        'qhost': {
+            'description': '%s暂不支持' % (
+                magenta('(New)')),
+            'option': {
+
+            }
         }
     }
