@@ -1,11 +1,10 @@
 import datetime
 import calendar
 import time
-from ..util.isix import STRING
+from ..const import STRING
 from terminal import green, white, red, yellow, cyan
 import os
 import re
-import math
 
 
 def get_cluster_state(state):
@@ -32,12 +31,28 @@ def get_job_state(state):
     else:
         return white(state)
 
+def get_job_state_simple(state):
+    s = state.lower() if state else state
+    if s=='running':
+        return 'R'
+    if s=='finished':
+        return 'C'
+    elif s=='waiting':
+        return 'W'
+    elif s=='failed':
+        return 'F'
+    elif s=='stopped':
+        return 'S'
+    else:
+        return state
+
 def filter_list(arr, filters):
     '''
     fitlers:
        1. {State:['Running','Waiting']}
        2. {NumRunningInstance: {'>': 1}}
        3. {JobName: {'like':'jobName1'}}
+       4. {JobName: {'startswith':'qsub-'}}
     '''
     t = []
 
@@ -49,20 +64,28 @@ def filter_list(arr, filters):
             alist = [ x.lower() for x in filters[k]]
             t = [item for item in arr if (item.get(k) != None and item.get(k).lower() in alist )]
         if isinstance(filters[k], dict):
+
+            startswith = filters[k].get('startswith')
+
             like = filters[k].get('like')
+
+
             gt = filters[k].get('>')
             lt = filters[k].get('<')
 
+            if startswith != None:
+                startswith = startswith.lower()
+                t = [item for item in arr if item.get(k).lower().startswith(startswith)]
 
-            if like != None:
+            elif like != None:
                 like = like.lower()
                 t = [item for item in arr if like in item.get(k).lower()]
-
             elif (gt != None or lt != None):
                 t = [item for item in arr
                      if (gt == None or gt != None and item.get(k) > gt) or (lt == None or lt != None and item.get(k) < lt)]
             else:
                 t = arr
+        arr = t
     return t
 
 def order_by(arr, cols, desc=None):
@@ -169,7 +192,7 @@ def get_abs_path(location):
         return os.path.join(os.getcwd(), location)
 
 def fix_log_path(s, jobId,taskName, instanceId, logType):
-    if s.endswith('.%s' % logType):
+    if s!='' and s.endswith('.%s' % logType):
         return '%s/%s.%s.%s.%s' % ( s[0:s.rfind('/')] , logType, jobId,taskName, instanceId )
     else:
         return s
@@ -190,9 +213,21 @@ def format_size(s):
         return '%sGB' % v
     if s > 1024*1024:
         v = int(s/1024/1024)
-        print(s)
         return '%sMB' % v
     if s > 1024:
         v = int(s/1024)
         return '%skB' % v
-    return '%sB' % s
\ No newline at end of file
+    return '%sB' % s
+
+def hex_job_id(jobId):
+    return '%s.console' % int('0x%s' % jobId[4:],16)
+
+def get_job_id(hexId):
+    ind = hexId.rfind('.')
+    if ind!=-1:
+        v = hexId[:ind]
+    else:
+        v = hexId
+    s = (hex(int(v))[2:-1]).upper()
+    return 'job-%s%s' % ('0'*(32-len(s)), s)
+
