@@ -2,7 +2,7 @@
 # -*- coding: UTF-8 -*-
 import json
 import os
-from ..util import client,it,result_cache, config
+from ..util import client,result_cache, config
 from terminal import yellow,blue
 from ..const import CMD
 import re
@@ -118,7 +118,16 @@ def trans_mount(s):
             k = item[0:ind]
             v = item[ind+1:]
         else:
-            [k,v]=item.split(':',1)
+            if ':oss://' in item:
+                ind = item.find(':oss://')
+                v = item[0:ind]
+                k = item[ind+1:]
+            elif ':nas://' in item:
+                ind = item.find(':nas://')
+                v = item[0:ind]
+                k = item[ind + 1:]
+            else:
+                [k,v]=item.split(':',1)
 
         if len(v)==1 and str.isalpha(v):
             v = v + ':'
@@ -184,16 +193,18 @@ def trans_disk(disk):
         result = {}
 
         for info in infos:
-
+            info = info.strip()
             if info.startswith('system:'):
                 (name, type, size) = info.split(':')
+                type = type.strip()
                 result['SystemDisk'] = {
-                    'Type': type, 'Size': int(size)
+                    'Type': '' if type=='default' else type, 'Size': int(size)
                 }
             elif info.startswith('data:'):
                 (name, type2, size2, mount_point) = info.split(':')
+                type2 = type2.strip()
                 result['DataDisk'] = {
-                    'Type': type2, 'Size': int(size2), 'MountPoint': mount_point
+                    'Type': '' if type2=='default' else type2, 'Size': int(size2), 'MountPoint': mount_point.strip()
                 }
             else:
                 raise Exception('Invalid disk format')
@@ -211,14 +222,16 @@ def set_default_type_n_image():
     # or not a available type
     m = config.getConfigs(config.COMMON)
     default_type = m.get('defaulttype')
+
     arr = client.list_instance_types()
-
+    
     if default_type:
-        for n in arr:
-            if default_type==n['name']:
-                return
-
-    m['defaulttype']=arr[0]['name']
+      for n in arr:
+        if default_type == n['name']:
+          return
+          
+    if len(arr)>0:
+       m['defaulttype'] = arr[0]['name']
 
     # if not found default image
     default_image = m.get('defaultimage')
